@@ -36,10 +36,10 @@ except ImportError as caught_exc:  # pragma: NO COVER
     )
 import requests.adapters  # pylint: disable=ungrouped-imports
 import requests.exceptions  # pylint: disable=ungrouped-imports
-from requests.packages.urllib3.util.ssl_ import (
+import six  # pylint: disable=ungrouped-imports
+from urllib3.util.ssl_ import (
     create_urllib3_context,
 )  # pylint: disable=ungrouped-imports
-import six  # pylint: disable=ungrouped-imports
 
 from google.auth import environment_vars
 from google.auth import exceptions
@@ -203,9 +203,9 @@ class _MutualTlsAdapter(requests.adapters.HTTPAdapter):
     """
 
     def __init__(self, cert, key):
-        pass
+        import certifi
         from OpenSSL import crypto
-        import urllib3.contrib.pyopenssl
+        import urllib3.contrib.pyopenssl  # type: ignore
 
         urllib3.contrib.pyopenssl.inject_into_urllib3()
 
@@ -213,13 +213,13 @@ class _MutualTlsAdapter(requests.adapters.HTTPAdapter):
         x509 = crypto.load_certificate(crypto.FILETYPE_PEM, cert)
 
         ctx_poolmanager = create_urllib3_context()
-        ctx_poolmanager.load_verify_locations(cafile="/etc/ssl/certs/ca-certificates.crt")
+        ctx_poolmanager.load_verify_locations(cafile=certifi.where())
         ctx_poolmanager._ctx.use_certificate(x509)
         ctx_poolmanager._ctx.use_privatekey(pkey)
         self._ctx_poolmanager = ctx_poolmanager
 
         ctx_proxymanager = create_urllib3_context()
-        ctx_proxymanager.load_verify_locations(cafile="/etc/ssl/certs/ca-certificates.crt")
+        ctx_proxymanager.load_verify_locations(cafile=certifi.where())
         ctx_proxymanager._ctx.use_certificate(x509)
         ctx_proxymanager._ctx.use_privatekey(pkey)
         self._ctx_proxymanager = ctx_proxymanager
